list-backups *SERVER_NAME*
:   Show available backups for `SERVER_NAME`. This command is useful to
    retrieve a backup ID. For example:

```
servername 20111104T102647 - Fri Nov  4 10:26:48 2011 - Size: 17.0 MiB - WAL Size: 100 B
```

    In this case, *20111104T102647* is the backup ID.
